# Deliveries

Types:

```python
from notiflows.types import Delivery
```

Methods:

- <code title="get /deliveries/{id}">client.deliveries.<a href="./src/notiflows/resources/deliveries.py">retrieve</a>(id) -> <a href="./src/notiflows/types/delivery.py">Delivery</a></code>
- <code title="get /deliveries">client.deliveries.<a href="./src/notiflows/resources/deliveries.py">list</a>(\*\*<a href="src/notiflows/types/delivery_list_params.py">params</a>) -> <a href="./src/notiflows/types/delivery.py">SyncCursorPage[Delivery]</a></code>

# Notifications

Types:

```python
from notiflows.types import Notification
```

Methods:

- <code title="get /notifications/{id}">client.notifications.<a href="./src/notiflows/resources/notifications.py">retrieve</a>(id) -> <a href="./src/notiflows/types/notification.py">Notification</a></code>
- <code title="get /notifications">client.notifications.<a href="./src/notiflows/resources/notifications.py">list</a>(\*\*<a href="src/notiflows/types/notification_list_params.py">params</a>) -> <a href="./src/notiflows/types/notification.py">SyncCursorPage[Notification]</a></code>
- <code title="get /notifications/{notification_id}/deliveries">client.notifications.<a href="./src/notiflows/resources/notifications.py">list_deliveries</a>(notification_id, \*\*<a href="src/notiflows/types/notification_list_deliveries_params.py">params</a>) -> <a href="./src/notiflows/types/delivery.py">SyncCursorPage[Delivery]</a></code>

# Notiflows

Types:

```python
from notiflows.types import NotiflowRunResponse
```

Methods:

- <code title="post /notiflows/{notiflow_handle}/run">client.notiflows.<a href="./src/notiflows/resources/notiflows.py">run</a>(notiflow_handle, \*\*<a href="src/notiflows/types/notiflow_run_params.py">params</a>) -> <a href="./src/notiflows/types/notiflow_run_response.py">NotiflowRunResponse</a></code>

# Topics

Types:

```python
from notiflows.types import Topic
```

Methods:

- <code title="get /topics/{id}">client.topics.<a href="./src/notiflows/resources/topics/topics.py">retrieve</a>(id) -> <a href="./src/notiflows/types/topic.py">Topic</a></code>
- <code title="get /topics">client.topics.<a href="./src/notiflows/resources/topics/topics.py">list</a>(\*\*<a href="src/notiflows/types/topic_list_params.py">params</a>) -> <a href="./src/notiflows/types/topic.py">SyncCursorPage[Topic]</a></code>
- <code title="delete /topics/{id}">client.topics.<a href="./src/notiflows/resources/topics/topics.py">delete</a>(id) -> None</code>

## Subscriptions

Types:

```python
from notiflows.types.topics import BulkOperationResponse, BulkSubscribeRequest
```

Methods:

- <code title="get /topics/{topic_id}/subscriptions">client.topics.subscriptions.<a href="./src/notiflows/resources/topics/subscriptions.py">list</a>(topic_id, \*\*<a href="src/notiflows/types/topics/subscription_list_params.py">params</a>) -> <a href="./src/notiflows/types/users/subscription.py">SyncCursorPage[Subscription]</a></code>
- <code title="post /topics/{topic_id}/subscriptions">client.topics.subscriptions.<a href="./src/notiflows/resources/topics/subscriptions.py">subscribe_bulk</a>(topic_id, \*\*<a href="src/notiflows/types/topics/subscription_subscribe_bulk_params.py">params</a>) -> <a href="./src/notiflows/types/topics/bulk_operation_response.py">BulkOperationResponse</a></code>
- <code title="delete /topics/{topic_id}/subscriptions">client.topics.subscriptions.<a href="./src/notiflows/resources/topics/subscriptions.py">unsubscribe_bulk</a>(topic_id, \*\*<a href="src/notiflows/types/topics/subscription_unsubscribe_bulk_params.py">params</a>) -> <a href="./src/notiflows/types/topics/bulk_operation_response.py">BulkOperationResponse</a></code>

# Users

Types:

```python
from notiflows.types import User
```

Methods:

- <code title="get /users/{user_external_id}">client.users.<a href="./src/notiflows/resources/users/users.py">retrieve</a>(user_external_id) -> <a href="./src/notiflows/types/user.py">User</a></code>
- <code title="get /users">client.users.<a href="./src/notiflows/resources/users/users.py">list</a>(\*\*<a href="src/notiflows/types/user_list_params.py">params</a>) -> <a href="./src/notiflows/types/user.py">SyncCursorPage[User]</a></code>
- <code title="delete /users/{user_external_id}">client.users.<a href="./src/notiflows/resources/users/users.py">delete</a>(user_external_id) -> None</code>
- <code title="put /users/{user_external_id}">client.users.<a href="./src/notiflows/resources/users/users.py">upsert</a>(user_external_id, \*\*<a href="src/notiflows/types/user_upsert_params.py">params</a>) -> <a href="./src/notiflows/types/user.py">User</a></code>

## ChannelSettings

Types:

```python
from notiflows.types.users import ChannelSettings, MobilePushSettings, SlackSettings
```

Methods:

- <code title="get /users/{user_external_id}/channel-settings/{channel_id}">client.users.channel_settings.<a href="./src/notiflows/resources/users/channel_settings.py">retrieve</a>(channel_id, \*, user_external_id) -> <a href="./src/notiflows/types/users/channel_settings.py">ChannelSettings</a></code>
- <code title="put /users/{user_external_id}/channel-settings/{channel_id}">client.users.channel_settings.<a href="./src/notiflows/resources/users/channel_settings.py">update</a>(channel_id, \*, user_external_id, \*\*<a href="src/notiflows/types/users/channel_setting_update_params.py">params</a>) -> <a href="./src/notiflows/types/users/channel_settings.py">ChannelSettings</a></code>
- <code title="delete /users/{user_external_id}/channel-settings/{channel_id}">client.users.channel_settings.<a href="./src/notiflows/resources/users/channel_settings.py">delete</a>(channel_id, \*, user_external_id) -> None</code>

## Deliveries

Methods:

- <code title="get /users/{user_external_id}/deliveries/{delivery_id}">client.users.deliveries.<a href="./src/notiflows/resources/users/deliveries.py">retrieve</a>(delivery_id, \*, user_external_id) -> <a href="./src/notiflows/types/delivery.py">Delivery</a></code>
- <code title="get /users/{user_external_id}/deliveries">client.users.deliveries.<a href="./src/notiflows/resources/users/deliveries.py">list</a>(user_external_id, \*\*<a href="src/notiflows/types/users/delivery_list_params.py">params</a>) -> <a href="./src/notiflows/types/delivery.py">SyncCursorPage[Delivery]</a></code>

## Notifications

Methods:

- <code title="get /users/{user_external_id}/notifications/{notification_id}">client.users.notifications.<a href="./src/notiflows/resources/users/notifications.py">retrieve</a>(notification_id, \*, user_external_id) -> <a href="./src/notiflows/types/notification.py">Notification</a></code>
- <code title="get /users/{user_external_id}/notifications">client.users.notifications.<a href="./src/notiflows/resources/users/notifications.py">list</a>(user_external_id, \*\*<a href="src/notiflows/types/users/notification_list_params.py">params</a>) -> <a href="./src/notiflows/types/notification.py">SyncCursorPage[Notification]</a></code>

## Preferences

Types:

```python
from notiflows.types.users import Preferences, UpdatePreferencesRequest
```

Methods:

- <code title="get /users/{user_external_id}/preferences">client.users.preferences.<a href="./src/notiflows/resources/users/preferences.py">retrieve</a>(user_external_id) -> <a href="./src/notiflows/types/users/preferences.py">Preferences</a></code>
- <code title="put /users/{user_external_id}/preferences">client.users.preferences.<a href="./src/notiflows/resources/users/preferences.py">update</a>(user_external_id, \*\*<a href="src/notiflows/types/users/preference_update_params.py">params</a>) -> <a href="./src/notiflows/types/users/preferences.py">Preferences</a></code>

## Subscriptions

Types:

```python
from notiflows.types.users import Subscription
```

Methods:

- <code title="get /users/{user_external_id}/subscriptions/{topic_name}">client.users.subscriptions.<a href="./src/notiflows/resources/users/subscriptions.py">retrieve</a>(topic_name, \*, user_external_id) -> <a href="./src/notiflows/types/users/subscription.py">Subscription</a></code>
- <code title="get /users/{user_external_id}/subscriptions">client.users.subscriptions.<a href="./src/notiflows/resources/users/subscriptions.py">list</a>(user_external_id, \*\*<a href="src/notiflows/types/users/subscription_list_params.py">params</a>) -> <a href="./src/notiflows/types/users/subscription.py">SyncCursorPage[Subscription]</a></code>
- <code title="post /users/{user_external_id}/subscriptions">client.users.subscriptions.<a href="./src/notiflows/resources/users/subscriptions.py">subscribe</a>(user_external_id, \*\*<a href="src/notiflows/types/users/subscription_subscribe_params.py">params</a>) -> <a href="./src/notiflows/types/users/subscription.py">Subscription</a></code>
- <code title="delete /users/{user_external_id}/subscriptions/{topic_name}">client.users.subscriptions.<a href="./src/notiflows/resources/users/subscriptions.py">unsubscribe</a>(topic_name, \*, user_external_id) -> None</code>
